zms._blobfields.MyBlob

Package zms :: Module _blobfields :: Class MyBlob |
[frames] | no frames]

# Class MyBlob

    object --+
             |
            MyBlob

Version: 0.1

Instance Methods
__str__(self) str(x) |
equals(self, ob) Indicates whether some other MyBlob-object is "equal to" this one. |
__bobo_traverse__(self, TraversalRequest, name) |
__call__(self, REQUEST=None, **kw) |
getObjAttrs(self, meta_type=None) |
getData(self, parent=None) Returns data. |
getHref(self, REQUEST) Returns absolute url. |
on_setobjattr(self) |
`string` |
getMediadbfile(self) Returns mediadb-filename. |
`string` |
getFilename(self) Returns filename. |
`int` |
get_real_size(self) Returns real size in ZODB. |
`string` |
getDataSizeStr(self) Returns display string for file-size (KB). |
`string` |
getContentType(self) Returns MIME-type (e.g. |
`string` |
getMimeTypeIconSrc(self) Returns the absolute-url of an icon representing the MIME-type of this MyBlob-object. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| __doc__ = `"""ZMS product module."""`
| __class_name__ = `'{{MyBlob}}'`
| __call____roles__ = `None`
| index_html = `None`
| getObjAttrs__roles__ = `None`
| getData__roles__ = `None`
| getHref__roles__ = `None`
| getMediadbfile__roles__ = `None`
| getFilename__roles__ = `None`
| get_size__roles__ = `None`
| get_real_size__roles__ = `None`
| getDataSizeStr__roles__ = `None`
| getContentType__roles__ = `None`
| getMimeTypeIconSrc__roles__ = `None`

Properties
Inherited from `object`: `__class__`

Method Details

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

### getHref(self, REQUEST) |
Returns absolute url. Parameters: `REQUEST` (ZPublisher.HTTPRequest)

### getDataSizeStr(self) |
Returns display string for file-size (KB). Returns: `string` Deprecated: Use standard.getDataSizeStr(len) instead!

### getContentType(self) |
Returns MIME-type (e.g. image/gif, text/xml). Returns: `string`

### getMimeTypeIconSrc(self) |
Returns the absolute-url of an icon representing the MIME-type of this MyBlob-object. Returns: `string` Deprecated: Use zmscontext.getMimeTypeIconSrc(mt) instead!